Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Forecasts ¶
func NewForecasts ¶
func (*Forecasts) InterpolatedMLForcast ¶
func (f *Forecasts) InterpolatedMLForcast(t time.Time) (*ScaledForecast, error)
InterpolatedMLForecast returns a version of a curated forecasts for the specified time, if possible. This version is scaled so that all factors are within the 0-1 range, as this is what would be needed for the training or usage of a Go neural network like the github.com/patrikeh/go-deep one. It returns an error if no interpolation is available and the only available forecast is more than 15 minutes away from the requested time. Interpolation is refused when there are more than 4 hours between the available adjacent forecasts (if any of the cornering forecasts is within a 15 minute window of the requested time, that cornering forecast is returned though).
func (*Forecasts) LoadForecastsSince ¶
LoadAllForecasts loads all existing forecasts from the database that happened at or after t.
func (*Forecasts) NextForecast ¶
func (f *Forecasts) NextForecast() *mosmix.CuratedForecast
type PVProductionEntry ¶ added in v0.0.3
type Pvdb ¶
type Pvdb struct {
// contains filtered or unexported fields
}
func (*Pvdb) EnsureTables ¶
func (p *Pvdb) EnsureTables()
func (*Pvdb) GetPVDataSince ¶ added in v0.0.3
func (*Pvdb) UpdatePVData ¶
func (p *Pvdb) UpdatePVData(data *loxonepv.PVDataList)
type ScaledForecast ¶
type ScaledForecast mosmix.CuratedForecast // alias to differentiate clearly
func (*ScaledForecast) String ¶
func (sf *ScaledForecast) String() string